Name:           unpaper
Version:        7.0.0
Release:    1%{?dist}
Summary:        Post-processing of scanned and photocopied book pages
License:        GPL-2.0-only AND 0BSD
URL:            https://www.flameeyes.eu/projects/%{name}
Source0:        https://www.flameeyes.eu/files/%{name}-%{version}.tar.xz
Patch0:         unpaper-7.0.0-Use-avformat_alloc_output_context2-to-create-the-out.patch
Patch1:         unpaper-7.0.0-Set-the-update-option-to-suppress-the-ffmpeg-5.1-war.patch
BuildRequires:  gcc
BuildRequires:  meson >= 0.57
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  python3-sphinx >= 3.4
BuildRequires:  python3dist(pytest)
BuildRequires:  python3-pillow

%description
unpaper is a post-processing tool for scanned sheets of paper, especially for
book pages that have been scanned from previously created photocopies. The
main purpose is to make scanned book pages better readable on screen after
conversion to PDF. Additionally, unpaper might be useful to enhance the
quality of scanned pages before performing optical character recognition (OCR).

unpaper tries to clean scanned images by removing dark edges that appeared
through scanning or copying on areas outside the actual page content (e.g. dark
areas between the left-hand-side and the right-hand-side of a double-sided
book-page scan).

The program also tries to detect misaligned centering and rotation of pages
and will automatically straighten each page by rotating it to the correct
angle. This process is called "deskewing".

%package tests
Summary:        Tests for %{name}
License:        GPL-2.0-only AND MIT
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
Requires:       python3-pillow
Requires:       python3-pytest
Requires:       python3-pytest-xdist

%description tests
Tests from %{name}. Execute them
with "%{_libexecdir}/%{name}/test".

%prep
%autosetup -p1

%build
%meson
%meson_build

%check
%meson_test

%install
%meson_install
mkdir -p %{buildroot}%{_libexecdir}/%{name}
cp -a tests %{buildroot}%{_libexecdir}/%{name}
cat > %{buildroot}%{_libexecdir}/%{name}/test << 'EOF'
export TEST_IMGSRC_DIR=tests/source_images
export TEST_GOLDEN_DIR=tests/golden_images
export TEST_UNPAPER_BINARY=%{_bindir}/unpaper
cd %{_libexecdir}/%{name} && exec pytest -v -n "$(getconf _NPROCESSORS_ONLN)" tests/unpaper_tests.py
EOF
chmod +x %{buildroot}%{_libexecdir}/%{name}/test
%{_fixperms} %{buildroot}/*

%files
%license LICENSES/0BSD.txt LICENSES/GPL-2.0-only.txt
%{_bindir}/*
%{_mandir}/man1/*
%doc AUTHORS doc/*.md doc/img NEWS README.md

%files tests
%license LICENSES/MIT.txt
%{_libexecdir}/%{name}

%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.0.0-1
- initial build
